@@ -7,14 +7,14 @@ from hnet.hnet import (
     import_example,
     )
 
-from hnet.utils.adjmat_vec import (
+from hnet.adjmat_vec import (
     vec2adjmat,
     adjmat2vec,
     )
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.0.12'
+__version__ = '1.1.8'
 
 # module level doc-string
 __doc__ = """
@@ -39,12 +39,15 @@ Examples
 >>> # Structure learning
 >>> out = hn.association_learning(df)
 
->>> # Plot dynamic graph
+>>> # Plot dynamic graphs
 >>> G = hn.d3graph()
+>>> G = hn.d3heatmap()
 >>> # Plot static graph
 >>> G = hn.plot()
 >>> # Plot heatmap
 >>> hn.heatmap(cluster=True)
+>>> # Plot feature importance
+>>> hn.plot_feat_importance()
 
 >>> # Examine differences between models
 >>> import hnet
