@@ -1,35 +1,94 @@
 # import hnet
 # print(dir(hnet))
 # print(hnet.__version__)
+
+# %%
 import numpy as np
+import pandas as pd
+
+
+# %%
 from hnet import hnet
 hn = hnet()
 df = hn.import_example('sprinkler')
 
-hn1 = hnet(dtypes=np.array(['bool']*df.shape[1]))
+hn1 = hnet(excl_background='0.0', dtypes=np.array(['bool']*df.shape[1]))
 out1 = hn1.association_learning(df.astype(bool))
 
 hn2 = hnet()
 out2 = hn2.association_learning(df.astype(bool))
 
+hn2.d3graph(summarize=True)
+hn2.d3graph()
+
+hn2.d3heatmap(summarize=True)
+hn2.d3heatmap(summarize=False)
+
+hn2.heatmap(summarize=True, cluster=False)
+hn2.heatmap(cluster=True)
+
+
+
+
+# %% Titanic case
+from hnet import hnet
+hn = hnet()
+df = hn.import_example('titanic')
+del df['PassengerId']
+del df['Name']
+results_new = hn.association_learning(df, verbose=4)
+
+# STATIC
+hn.heatmap(summarize=False, cluster=False)
+hn.plot(node_color='cluster')
+
+# Feature importance
+hn.plot_feat_importance(marker_size=50)
+
+hn.d3heatmap('c:/temp/titanic_summarize/')
+hn.d3graph('c:/temp/titanic_summarize_d3graph/')
+
+
+# %% Penguins dataset
+import seaborn as sns
+from hnet import hnet
+
+df = sns.load_dataset("penguins")
+
+hn = hnet()
+results_new = hn.association_learning(df, verbose=3)
+
+hn.d3graph()
+hn.d3heatmap()
+
+hn.d3graph(summarize=True)
+hn.d3heatmap(summarize=True)
+hn.plot_feat_importance(marker_size=50)
+
+# %% Timimg checks
+from pycallgraph import PyCallGraph
+from pycallgraph.output import GraphvizOutput
+
+with PyCallGraph(output=GraphvizOutput()):
+    results = hn.association_learning(df)
+
+
 # %%
 import hnet
 df = hnet.import_example('sprinkler')
-out = hnet.enrichment(df.astype(bool), y=df.iloc[:,0].values)
+out = hnet.enrichment(df.astype(bool), y=df.iloc[:, 0].values)
 print(out)
 
-
 import hnet
 dtypes = np.array(['bool']*df.shape[1])
 df = hnet.import_example('sprinkler')
-out = hnet.enrichment(df.astype(bool), y=df.iloc[:,0].values, dtypes=dtypes)
+out = hnet.enrichment(df.astype(bool), y=df.iloc[:, 0].values, dtypes=dtypes)
 print(out)
 
-# %%
-
 # %%
 # Load data
 # df = hn.import_example('titanic')
+from hnet import hnet
 hn = hnet()
 df = hn.import_example('sprinkler')
 
@@ -43,16 +102,23 @@ out3 = hn.association_learning(df.astype(int))
 hn.plot()
 
 hn = hnet(excl_background='False')
-out5 = hn.association_learning(df.astype(bool).astype(str))
+hn.association_learning(df.astype(bool).astype(str))
+hn.plot(summarize=True)
 
 hn = hnet(excl_background='0')
 out7 = hn.association_learning(df.astype(int).astype(str))
+hn.plot(summarize=False)
+hn.plot(summarize=True)
 
 hn = hnet(excl_background='0.0')
 out6 = hn.association_learning(df.astype(float).astype(str))
+hn.plot(summarize=False)
+hn.plot(summarize=True)
 
 # Should raise exception
 out4 = hn.association_learning(df.astype(float))
+hn.plot(summarize=False)
+hn.plot(summarize=True)
 
 
 # %% Import class
@@ -75,7 +141,8 @@ results = hn.association_learning(df)
 
 # out = tabulate(hn.results['rules'].iloc[1:,:].head(), tablefmt="grid", headers="keys")
 
-hn.d3graph()
+hn.d3heatmap(figsize=(1000,1000))
+hn.d3graph(node_color='cluster')
 hn.d3graph(min_edges=5)
 # hn.d3graph(savepath='D://PY/REPOSITORIES/erdogant.github.io/docs/d3graph/income/')
 
@@ -89,15 +156,22 @@ df = hnet.import_example('student')
 
 df = hnet.import_example('sprinkler')
 
+# %% Run with default settings
+import hnet
+df = hnet.import_example('titanic')
+from hnet import hnet
+hn = hnet()
+results = hn.association_learning(df)
+
 # %% Run with default settings
 from hnet import hnet
 
 hn = hnet()
 # Load data
-# df = hn.import_example('titanic')
+df = hn.import_example('titanic')
 df = hn.import_example('sprinkler')
 # Association learning
-out = hn.association_learning(df.astype(bool))
+results = hn.association_learning(df.astype(bool))
 
 # %% Plot with clustering nodes
 G_static = hn.plot()
@@ -112,6 +186,9 @@ G_static = hn.plot(node_color='cluster')
 # Plot heatmap
 P_heatmap = hn.heatmap(cluster=True)
 
+# Plot heatmap
+paths = hn.d3heatmap()
+
 # %%
 import matplotlib.pyplot as plt
 P = hn.results['simmatLogP'].values.ravel()
@@ -134,6 +211,7 @@ df = hn1.import_example('titanic')
 out1 = hn1.association_learning(df)
 out2 = hn2.association_learning(df)
 
+
 # Import hnet functionalities
 import hnet
 # Examine differences between models
@@ -292,3 +370,52 @@ df = pd.read_csv('D://covid19_us_county.zip')
 dtypes = ['', 'cat', 'cat', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num', 'num']
 hn = hnet(dtypes=dtypes)
 results = hn.association_learning(df)
+
+# %% Police shooting
+# https://github.com/washingtonpost/data-police-shootings
+import pandas as pd
+from hnet import hnet
+import time
+
+hn = hnet(excl_background=['nan'], black_list=['id', 'date', 'name'])
+
+# Load results
+results = hn.load(filepath='C://temp//data-police-shootings/hnet.pkl')
+
+# Run hnet
+if results is None:
+
+    # Read csv
+    df = pd.read_csv('C://temp/police_shooting.csv')
+    df['month'] = pd.to_datetime(df['date']).dt.month_name()
+    df.head()
+    # Initialize
+    hn = hnet(excl_background=['nan'], black_list=['id', 'date', 'name'])
+
+    start = time.time()
+    # Association learning
+    results = hn.association_learning(df, verbose=4)
+    print(time.time()- start)
+
+
+    # with PyCallGraph(output=GraphvizOutput()):
+    #     results = hn.association_learning(df, verbose=4)
+    # end = time.time()
+    # print(end - start)
+
+    # Save
+    hn.save(filepath='C://temp/New folder/data-police-shootings/hnet.pkl', overwrite=True)
+
+# Plot dynamic graph
+hn.d3graph()
+hn.d3graph(black_list=['city'])
+hn.d3graph(black_list=['city', 'state'])
+hn.d3graph(summarize=True)
+
+# Plot heatmap
+hn.d3heatmap(black_list=['city', 'state'])
+hn.d3heatmap(black_list=['city', 'state', 'longitude', 'latitude'])
+hn.d3heatmap(summarize=True, vmax=5)
+
+# Feature importance
+hn.plot_feat_importance()
